#!/bin/bash
#
# nohup ./nccf_atm_daily.sh EXPID startdate >& EXPID-startdate.log &
#
# This script will extract variabls from EC-Earth daily atmospheric output 
# which is available in ICMGG* & ICMSH* files, save each variable in one file 
# and also combine members together. It will modify the header informaton 
# of the generated files according to CMIP5 standard and the variable names 
# will be modified according PCMDI standard variable names.
#
# Written by Hui Du
#
# Institut Català de Ciències del Clima / Climate Forecasting Unit (IC3/CFU)
# Created:  February 22, 2010

set -xv


msg='Your experiment crashed! Your workdir \($WORKDIR\) will be kept for one week from now and then deleted'
trap "echo $msg ; delete ; exit" SIGINT SIGHUP SIGTERM SIGSEGV SIGKILL 


date

. ./functions.bash
config_file=$1

check_args $@
sed -i -e 's/= /=/g' ${config_file}
. ${config_file}

ENSEMBLE=${#MEM_LST[@]}
FACTOR=$((NFRP*3600))           # 3600 (seconds per hour)
rm -rf ${WORKDIR}
mkdir -p ${WORKDIR}
if [[ ! -d ${WORKDIR} ]]; then
 exit 1
fi
cd ${WORKDIR}


ENSEMBLE=${#MEM_LST[@]}
if [[ $ENSEMBLE -eq 0 ]]; then
  MEM_LST=( $( ls ${DATADIR}/${EXPID}/${SDATE} ) )
  ENSEMBLE=${#MEM_LST[@]}
  echo "Warning: you passed an empty member list. By default, it will treat all the available members: " ${MEM_LST[@]}
fi


# seperate and count 2D&3D varaibles
j=1
k=1
for var in ${VAR_LST}; do
        case $var in
                T2M|SST|MSL|PRECIP|SSR|STR|SLHF|SSHF|D2M|U10M|V10M|SD|SSRD|STRD|TTR|TSR|Q|E|STL1|TCC|MX2T|MN2T)
                        VAR_LST_2D[$j]="$var"
                        j=$((j+1))
                ;;
                T|U|V|Z)
                        VAR_LST_3D[$k]="$var"
                        k=$((k+1))
                ;;
        esac
done

# prepare yyyymm list in some file (member is hard-coded here?) 
ls ${DATADIR}/${EXPID}/${SDATE}/fc0/outputs/ICMGG*.grb|cut -f2 -d'+'|cut -c1-6 > yearmonth_lst
# main loop for performing post-processing
cat yearmonth_lst > subset_data
while read line; do
	yyyymm=$line
	suffix=${SDATE}_$yyyymm
	get_reftime $yyyymm
	
	if [[ ${#VAR_LST_2D[@]} -gt 0 ]]; then
	    header $yyyymm ${INTERVAL_MXMN}; mv header.nc header_MXMN.nc
	    header $yyyymm ${INTERVAL}
		generate_netcdf_surface  $yyyymm
		modify_header
		if [ -e hus_${suffix}.nc ];then
			modify_var_upper Q
			save_final_output Q
		fi
	fi
	
	if [[ ${#VAR_LST_3D[@]} -gt 0 ]]; then
	    header $yyyymm ${INTERVAL_3D}; mv header.nc header_3D.nc
		generate_netcdf_upper  $yyyymm
		modify_header_3D
	fi
	rm -f ${WORKDIR}/*.nc
done < subset_data

date
####  End of the Main Part of Script  ####
